@@ -41,7 +41,7 @@ extensions = [
     ]
 
 # for sitemap with https://github.com/jdillard/sphinx-sitemap
-site_url = "https://www.mdacli.mdanalysis.org/"
+site_url = "https://mdacli.mdanalysis.org/"
 
 todo_include_todos = True
 
@@ -62,7 +62,7 @@ project = 'mdacli'
 year = '2021'
 author = 'Philip Loche, Joao MC Teixeira and Oliver Beckstein'
 copyright = '{0}, {1}'.format(year, author)
-version = release = '0.1.5'
+version = release = '0.1.6'
 
 pygments_style = 'trac'
 templates_path = ['_templates']
